# MiningPersonalityInGerman
MiningPersonalityInGerman (MiPInG)

Mining Personality In German (MiPinG) predicts your Big Five personality score based on your public Twitter profile. Simply enter your Twitter username and we will analyze the language of your Tweets. To learn more about MiPinG go to https://miping.de/ or visit our GitHub https://github.com/iUssel/MiningPersonalityInGerman.

Please check https://github.com/iUssel/MiningPersonalityInGerman/blob/master/docs/main.html for detailed source code documentation.
For further documentation check https://github.com/iUssel/MiningPersonalityInGerman/blob/master/docs/SettingUpMiPinG.pdf and https://github.com/iUssel/MiningPersonalityInGerman/blob/master/docs/TrainingMiPinG.pdf .

Copyright 2020 Henning Usselmann

Licensed under the Apache License, Version 2.0 (the "License");
you may not use this file except in compliance with the License.
You may obtain a copy of the License at

   http://www.apache.org/licenses/LICENSE-2.0

Unless required by applicable law or agreed to in writing, software
distributed under the License is distributed on an "AS IS" BASIS,
WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
See the License for the specific language governing permissions and
limitations under the License.
